@@ -46,6 +46,7 @@ try:
 except ImportError:
     from kamaki.clients.commissioning.utils.ordereddict import OrderedDict
 
+
 def shorts(s):
     if not isinstance(s, unicode):
         s = str(s)
@@ -59,6 +60,7 @@ def shorts(s):
 class CanonifyException(Exception):
     pass
 
+
 class SpecifyException(Exception):
     pass
 
@@ -159,15 +161,14 @@ class Canonical(object):
             joinchar = ',\n'
             padchar = '\n'
 
-        args = [a.tostring( depth=depth,
-                            showopts=showopts,
-                            multiline=multiline) for a in self.args]
-        args += [("%s=%s" %
-                    (k, v.tostring( depth=depth,
-                                    showopts=showopts,
-                                    multiline=multiline)))
-
-                                    for k, v in self.kw.items()]
+        args = [a.tostring(
+            depth=depth,
+            showopts=showopts,
+            multiline=multiline) for a in self.args]
+        args += [("%s=%s" % (k, v.tostring(
+            depth=depth,
+            showopts=showopts,
+            multiline=multiline))) for k, v in self.kw.items()]
         if showopts:
             args += [("%s=%s" % (k, str(v))) for k, v in self.opts.items()]
 
@@ -194,6 +195,7 @@ class Canonical(object):
     def _show(self):
         return self.name
 
+
 class Null(Canonical):
 
     def _check(self, item):
@@ -207,13 +209,13 @@ class Integer(Canonical):
     def _check(self, item):
         try:
             num = long(item)
-        except ValueError, e:
+        except ValueError:
             try:
                 num = long(item, 16)
             except Exception:
                 m = "%s: cannot convert '%s' to long" % (self, shorts(item))
                 raise CanonifyException(m)
-        except TypeError, e:
+        except TypeError:
             m = "%s: cannot convert '%s' to long" % (self, shorts(item))
             raise CanonifyException(m)
 
@@ -246,11 +248,7 @@ class Integer(Canonical):
         return long(minimum + r * (maximum - minimum))
 
 
-
-Serial = Integer(
-            classname   =   'Serial',
-            null        =   True,
-)
+Serial = Integer(classname='Serial', null=True)
 
 
 class Text(Canonical):
@@ -272,8 +270,9 @@ class Text(Canonical):
             self.pat = pat
 
         if 'choices' in opts:
-            opts['choices'] = dict((unicode(x), unicode(x))
-                                    for x in opts['choices'])
+            opts['choices'] = dict((
+                unicode(x),
+                unicode(x)) for x in opts['choices'])
 
     def _check(self, item):
         if not isinstance(item, unicode):
@@ -316,11 +315,11 @@ class Text(Canonical):
         matcher = self.matcher
         if matcher is not None:
             match = matcher.match(item)
-            if  (       match is None
-                    or  (match.start(), match.end()) != (0, itemlen)    ):
-
-                    m = ("%s: '%s' does not match '%s'"
-                            % (self, shorts(item), self.pat))
+            if ((not match) or (match.start(), match.end()) != (0, itemlen)):
+                    m = ("%s: '%s' does not match '%s'" % (
+                        self,
+                        shorts(item),
+                        self.pat))
                     raise CanonifyException(m)
 
         return item
@@ -344,7 +343,7 @@ class Text(Canonical):
 
         g = log(z, 2)
         r = random() * g
-        z = minlen + int(2**r)
+        z = minlen + int(2 ** r)
 
         s = u''
         for _ in xrange(z):
@@ -372,8 +371,7 @@ class Bytes(Canonical):
             self.pat = pat
 
         if 'choices' in opts:
-            opts['choices'] = dict((str(x), str(x))
-                                    for x in opts['choices'])
+            opts['choices'] = dict((str(x), str(x)) for x in opts['choices'])
 
     def _check(self, item):
         if isinstance(item, unicode):
@@ -410,11 +408,11 @@ class Bytes(Canonical):
         matcher = self.matcher
         if matcher is not None:
             match = matcher.match(item)
-            if  (       match is None
-                    or  (match.start(), match.end()) != (0, itemlen)    ):
-
-                    m = ("%s: '%s' does not match '%s'"
-                            % (self, shorts(item), self.pat))
+            if ((not match) or (match.start(), match.end()) != (0, itemlen)):
+                    m = ("%s: '%s' does not match '%s'" % (
+                        self,
+                        shorts(item),
+                        self.pat))
                     raise CanonifyException(m)
 
         return item
@@ -438,7 +436,7 @@ class Bytes(Canonical):
 
         g = log(z, 2)
         r = random() * g
-        z = minlen + int(2**r)
+        z = minlen + int(2 ** r)
 
         s = u''
         for _ in xrange(z):
@@ -475,7 +473,7 @@ class ListOf(Canonical):
 
         try:
             items = iter(item)
-        except TypeError, e:
+        except TypeError:
             m = "%s: %s is not iterable" % (self, shorts(item))
             raise CanonifyException(m)
 
@@ -502,6 +500,7 @@ class ListOf(Canonical):
     def _show(self):
         return '[ ' + self.canonical.show() + ' ... ]'
 
+
 class Args(Canonical):
 
     def _unpack(self, item):
@@ -510,7 +509,8 @@ class Args(Canonical):
         arglen = len(arglist)
         if arglen != len(keys):
             m = "inconsistent number of parameters: %s != %s" % (
-            arglen, len(keys))
+                arglen,
+                len(keys))
             raise CanonifyException(m)
 
         position = 0
@@ -524,8 +524,8 @@ class Args(Canonical):
                 for i in range(position, arglen):
                     key = keys[i]
                     if not key in named_args.keys():
-                       position = i + 1
-                       break
+                        position = i + 1
+                        break
                 else:
                     m = "Formal arguments exhausted"
                     raise AssertionError(m)
@@ -535,8 +535,8 @@ class Args(Canonical):
 
     def _check(self, item):
         try:
-            arglist = OrderedDict(item).items()
-        except (TypeError, ValueError), e:
+            OrderedDict(item).items()
+        except (TypeError, ValueError):
             m = "%s: %s is not dict-able" % (self, shorts(item))
             raise CanonifyException(m)
 
@@ -569,7 +569,7 @@ class Tuple(Canonical):
     def _check(self, item):
         try:
             items = list(item)
-        except TypeError, e:
+        except TypeError:
             m = "%s: %s is not iterable" % (self, shorts(item))
             raise CanonifyException(m)
 
@@ -578,7 +578,11 @@ class Tuple(Canonical):
         zc = len(canonicals)
 
         if zi != zc:
-            m = "%s: expecting %d elements, not %d (%s)" % (self, zc, zi, str(items))
+            m = "%s: expecting %d elements, not %d (%s)" % (
+                self,
+                zc,
+                zi,
+                str(items))
             raise CanonifyException(m)
 
         g = (canonical(element) for canonical, element in zip(self.args, item))
@@ -598,6 +602,7 @@ class Tuple(Canonical):
         strings = [x for x in [c.show() for c in canonicals] if x]
         return '[ ' + ' '.join(strings) + ' ]'
 
+
 class Dict(Canonical):
 
     def _check(self, item):
@@ -731,15 +736,16 @@ class Specificator(object):
             deflen = len(defaults)
 
             if arglen != deflen:
-                a = (f.__name__, args[:arglen-deflen])
+                a = (f.__name__, args[:arglen - deflen])
                 m = "Unspecified arguments in '%s': %s" % a
                 raise SpecifyException(m)
 
             args = zip(args, defaults)
             for a, c in args:
                 if not isinstance(c, Canonical):
-                    m = ("argument '%s=%s' is not an instance of 'Canonical'"
-                         % (a, repr(c)))
+                    m = ("argument '%s=%s' not an instance of 'Canonical'" % (
+                        a,
+                        repr(c)))
                     raise SpecifyException(m)
 
             canonical = Null() if len(args) == 0 else Args(*args)
@@ -748,9 +754,9 @@ class Specificator(object):
             self = object.__new__(cls)
             canonical = f(self)
             if not isinstance(canonical, Canonical):
-                m = ("method '%s' does not return a Canonical, but a(n) %s "
-                                                    % (name, type(canonical)))
-                raise SpecifyException(m)
+                raise SpecifyException(', '.join([
+                    "method %s does not return a Canonical" % name,
+                    "but a (n) %s" % type(canonical)]))
             canonical_outputs[name] = canonical
 
         return Canonifier(cls.__name__, canonical_inputs, canonical_outputs,
@@ -758,4 +764,3 @@ class Specificator(object):
 
     def __call__(self):
         return self
-
